@@ -14,7 +14,7 @@
 
 #include "asm-generic/int.h"
 
-#include "compiler.h"
+#include "common/compiler.h"
 #include "piegen.h"
 
 static bool __ptr_oob(const void *ptr, const void *start, const size_t size)
@@ -47,10 +47,10 @@ static bool test_pointer(const void *ptr, const void *start, const size_t size,
 static int do_relative_toc(long value, uint16_t *location,
 			   unsigned long mask, int complain_signed)
 {
-        if (complain_signed && (value + 0x8000 > 0xffff)) {
+	if (complain_signed && (value + 0x8000 > 0xffff)) {
 		pr_err("TOC16 relocation overflows (%ld)\n", value);
 		return -1;
-        }
+	}
 
 	if ((~mask & 0xffff) & value) {
 		pr_err("bad TOC16 relocation (%ld) (0x%lx)\n", value, (~mask & 0xffff) & value);
@@ -158,7 +158,7 @@ int handle_elf(void *mem, size_t size)
 	}
 
 	pr_out("/* Autogenerated from %s */\n", opts.input_filename);
-	pr_out("#include \"piegen/uapi/types.h\"\n");
+	pr_out("#include \"%s/types.h\"\n", opts.uapi_dir);
 
 	for (i = 0; i < symtab_hdr->sh_size / symtab_hdr->sh_entsize; i++) {
 		Sym_t *sym = &symbols[i];
@@ -341,7 +341,7 @@ int handle_elf(void *mem, size_t size)
 				}
 				/* Only replace bits 2 through 26 */
 				*(uint32_t *)where = (*(uint32_t *)where & ~0x03fffffc) |
-                                        (value64 & 0x03fffffc);
+					(value64 & 0x03fffffc);
 				break;
 
 			case R_PPC64_ADDR32:
